VirtualFluids 0.2.0
Parallel CFD LBM Solver
Loading...
Searching...
No Matches
NoSlip.cu
Go to the documentation of this file.
1//=======================================================================================
2// ____ ____ __ ______ __________ __ __ __ __
3// \ \ | | | | | _ \ |___ ___| | | | | / \ | |
4// \ \ | | | | | |_) | | | | | | | / \ | |
5// \ \ | | | | | _ / | | | | | | / /\ \ | |
6// \ \ | | | | | | \ \ | | | \__/ | / ____ \ | |____
7// \ \ | | |__| |__| \__\ |__| \________/ /__/ \__\ |_______|
8// \ \ | | ________________________________________________________________
9// \ \ | | | ______________________________________________________________|
10// \ \| | | | __ __ __ __ ______ _______
11// \ | | |_____ | | | | | | | | | _ \ / _____)
12// \ | | _____| | | | | | | | | | | \ \ \_______
13// \ | | | | |_____ | \_/ | | | | |_/ / _____ |
14// \ _____| |__| |________| \_______/ |__| |______/ (_______/
15//
16// This file is part of VirtualFluids. VirtualFluids is free software: you can
17// redistribute it and/or modify it under the terms of the GNU General Public
18// License as published by the Free Software Foundation, either version 3 of
19// the License, or (at your option) any later version.
20//
21// VirtualFluids is distributed in the hope that it will be useful, but WITHOUT
22// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
23// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
24// for more details.
25//
26// SPDX-License-Identifier: GPL-3.0-or-later
27// SPDX-FileCopyrightText: Copyright © VirtualFluids Project contributors, see AUTHORS.md in root folder
28//
29//! \addtogroup gpu_BoundaryConditions BoundaryConditions
30//! \ingroup gpu_core core
31//! \{
32//! \author Martin Schoenherr
33//=======================================================================================
34#include <cuda_runtime.h>
35#include <helper_functions.h>
36#include <helper_cuda.h>
37
38#include "Calculation/Calculation.h"
39#include <cuda_helper/CudaGrid.h>
40
41#include "BoundaryConditions/NoSlip/NoSlip_Device.cuh"
42#include "Parameter/Parameter.h"
43
44namespace vf::gpu {
45
46void NoSlipBounceBack(LBMSimulationParameter* parameterDevice, QforBoundaryConditions* boundaryCondition)
47{
48 dim3 grid = vf::cuda::getCudaGrid( parameterDevice->numberofthreads, boundaryCondition->numberOfBCnodes);
49 dim3 threads(parameterDevice->numberofthreads, 1, 1 );
50
51 NoSlipBounceBack_Device<<< grid, threads >>> (
52 parameterDevice->distributions.f[0],
53 boundaryCondition->k,
54 boundaryCondition->q27[0],
55 boundaryCondition->numberOfBCnodes,
56 parameterDevice->neighborX,
57 parameterDevice->neighborY,
58 parameterDevice->neighborZ,
59 parameterDevice->numberOfNodes,
60 parameterDevice->isEvenTimestep);
61 getLastCudaError("NoSlipBounceBack_Device execution failed");
62}
63
64void NoSlipInterpolatedIncompressible(LBMSimulationParameter* parameterDevice, QforBoundaryConditions* boundaryCondition)
65{
66 dim3 grid = vf::cuda::getCudaGrid( parameterDevice->numberofthreads, boundaryCondition->numberOfBCnodes);
67 dim3 threads(parameterDevice->numberofthreads, 1, 1 );
68
69 NoSlipInterpolatedIncompressible_Device<<< grid, threads >>> (
70 parameterDevice->distributions.f[0],
71 boundaryCondition->k,
72 boundaryCondition->q27[0],
73 boundaryCondition->numberOfBCnodes,
74 parameterDevice->omega,
75 parameterDevice->neighborX,
76 parameterDevice->neighborY,
77 parameterDevice->neighborZ,
78 parameterDevice->numberOfNodes,
79 parameterDevice->isEvenTimestep);
80 getLastCudaError("NoSlipInterpolatedIncompressible_Device execution failed");
81}
82
83void NoSlipInterpolatedCompressible(LBMSimulationParameter* parameterDevice, QforBoundaryConditions* boundaryCondition)
84{
85 dim3 grid = vf::cuda::getCudaGrid( parameterDevice->numberofthreads, boundaryCondition->numberOfBCnodes);
86 dim3 threads(parameterDevice->numberofthreads, 1, 1 );
87
88 NoSlipInterpolatedCompressible_Device<<< grid, threads >>> (
89 parameterDevice->distributions.f[0],
90 boundaryCondition->k,
91 boundaryCondition->q27[0],
92 boundaryCondition->numberOfBCnodes,
93 parameterDevice->omega,
94 parameterDevice->neighborX,
95 parameterDevice->neighborY,
96 parameterDevice->neighborZ,
97 parameterDevice->numberOfNodes,
98 parameterDevice->isEvenTimestep);
99 getLastCudaError("NoSlipInterpolatedCompressible_Device execution failed");
100}
101
102}
103
104//! \}